@@ -82,7 +82,7 @@ class Trollop < ::Test::Unit::TestCase
 
     # single arg: int
     assert_nothing_raised { @p.opt "argsi", "desc", :default => 0 }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal 0, opts["argsi"]
     assert_nothing_raised { opts = @p.parse(%w(--argsi 4)) }
     assert_equal 4, opts["argsi"]
@@ -91,18 +91,20 @@ class Trollop < ::Test::Unit::TestCase
 
     # single arg: float
     assert_nothing_raised { @p.opt "argsf", "desc", :default => 3.14 }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal 3.14, opts["argsf"]
     assert_nothing_raised { opts = @p.parse(%w(--argsf 2.41)) }
     assert_equal 2.41, opts["argsf"]
     assert_nothing_raised { opts = @p.parse(%w(--argsf 2)) }
     assert_equal 2, opts["argsf"]
+    assert_nothing_raised { opts = @p.parse(%w(--argsf 1.0e-2)) }
+    assert_equal 1.0e-2, opts["argsf"]
     assert_raise(CommandlineError) { @p.parse(%w(--argsf hello)) }
 
     # single arg: date
     date = Date.today
     assert_nothing_raised { @p.opt "argsd", "desc", :default => date }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal Date.today, opts["argsd"]
     assert_nothing_raised { opts = @p.parse(['--argsd', 'Jan 4, 2007']) }
     assert_equal Date.civil(2007, 1, 4), opts["argsd"]
@@ -110,7 +112,7 @@ class Trollop < ::Test::Unit::TestCase
 
     # single arg: string
     assert_nothing_raised { @p.opt "argss", "desc", :default => "foobar" }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal "foobar", opts["argss"]
     assert_nothing_raised { opts = @p.parse(%w(--argss 2.41)) }
     assert_equal "2.41", opts["argss"]
@@ -119,7 +121,7 @@ class Trollop < ::Test::Unit::TestCase
 
     # multi args: ints
     assert_nothing_raised { @p.opt "argmi", "desc", :default => [3, 5] }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal [3, 5], opts["argmi"]
     assert_nothing_raised { opts = @p.parse(%w(--argmi 4)) }
     assert_equal [4], opts["argmi"]
@@ -128,7 +130,7 @@ class Trollop < ::Test::Unit::TestCase
 
     # multi args: floats
     assert_nothing_raised { @p.opt "argmf", "desc", :default => [3.34, 5.21] }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal [3.34, 5.21], opts["argmf"]
     assert_nothing_raised { opts = @p.parse(%w(--argmf 2)) }
     assert_equal [2], opts["argmf"]
@@ -139,7 +141,7 @@ class Trollop < ::Test::Unit::TestCase
     # multi args: dates
     dates = [Date.today, Date.civil(2007, 1, 4)]
     assert_nothing_raised { @p.opt "argmd", "desc", :default => dates }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal dates, opts["argmd"]
     assert_nothing_raised { opts = @p.parse(['--argmd', 'Jan 4, 2007']) }
     assert_equal [Date.civil(2007, 1, 4)], opts["argmd"]
@@ -147,7 +149,7 @@ class Trollop < ::Test::Unit::TestCase
 
     # multi args: strings
     assert_nothing_raised { @p.opt "argmst", "desc", :default => %w(hello world) }
-    assert_nothing_raised { opts = @p.parse("--") }
+    assert_nothing_raised { opts = @p.parse(%w(--)) }
     assert_equal %w(hello world), opts["argmst"]
     assert_nothing_raised { opts = @p.parse(%w(--argmst 3.4)) }
     assert_equal ["3.4"], opts["argmst"]
@@ -1039,9 +1041,53 @@ EOM
 
   def test_multi_args_default_to_empty_array
     @p.opt :arg1, "arg", :multi => true
-    opts = @p.parse ""
+    opts = @p.parse []
     assert_equal [], opts[:arg1]
   end
+
+  def test_simple_interface_handles_help
+    ARGV.clear
+    ARGV.unshift "-h"
+    assert_raises(SystemExit) do
+      opts = ::Trollop::options do
+        opt :potato
+      end
+      raise "broken"
+    end
+  end
+
+  def test_simple_interface_handles_version
+    ARGV.clear
+    ARGV.unshift "-v"
+    assert_raises(SystemExit) do
+      opts = ::Trollop::options do
+        version "1.2"
+        opt :potato
+      end
+      raise "broken"
+    end
+  end
+
+  def test_simple_interface_handles_regular_usage
+    ARGV.clear
+    ARGV.unshift "--potato"
+    opts = nil
+    assert_nothing_raised do
+      opts = ::Trollop::options do
+        opt :potato
+      end
+    end
+    assert opts[:potato]
+  end
+
+  def test_simple_interface_handles_die
+    ARGV.clear
+    ARGV.unshift "--potato"
+    opts = ::Trollop::options do
+      opt :potato
+    end
+    assert_raises(SystemExit) { ::Trollop::die :potato, "is invalid" }
+  end
 end
 
 end
